@@ -1,106 +1,132 @@
-use 5.12.0;
+use 5.10.1;
+use strict;
 use warnings;
 
-package Dist::Iller::Config::Author::CSSON {
+package Dist::Iller::Config::Author::CSSON;
 
-    our $VERSION = '0.0200'; # VERSION
-    # ABSTRACT: Dist::Iller config
+our $VERSION = '0.0201'; # VERSION
+# ABSTRACT: Dist::Iller config
 
-    use Moose;
-    use Path::Tiny;
-    use Types::Path::Tiny qw/Path/;
-    use Types::Standard qw/Bool Str Int/;
-    use MooseX::AttributeDocumented;
+use Moose;
+use namespace::autoclean;
+use Path::Tiny;
+use Types::Path::Tiny qw/Path/;
+use Types::Standard qw/Bool Str Int/;
+use MooseX::AttributeDocumented;
 
-    has filepath => (
-        is => 'ro',
-        isa => Path,
-        default => 'author-csson.yaml',
-        coerce => 1,
-        documentation => q{Path to the plugin configuration file, relative to the installed share dir location.},
-    );
-    has is_task => (
-        is => 'ro',
-        isa => Bool,
-        default => 0,
-        documentation => q{If set to a true value it will include [TaskWeaver] instead of [PodWeaver].},
-    );
-    has installer => (
-        is => 'rw',
-        isa => Str,
-        lazy => 1,
-        default => 'MakeMaker',
-        documentation => q{The installer plugin to be used.},
-    );
-    has is_private => (
-        is => 'rw',
-        isa => Int,
-        lazy => 1,
-        default => 0,
-        documentation_alts => {
-            0 => q{Include [UploadToCPAN] and [GithubMeta].},
-            1 => q{Include [UploadToStratopan].},
-        }
-    );
-    has homepage => (
-        is => 'rw',
-        isa => Str,
-        lazy => 1,
-        default => sub { sprintf 'https://metacpan.org/release/' . shift->distribution_name },
-        documentation_default => q{https://metacpan.org/release/[distribution_name]},
-        documentation => q{URL to the distribution's homepage.},
-    );
-    has splint => (
-        is => 'rw',
-        isa => Int,
-        default => 0,
-        documentation_alts => {
-            0 => q{Exclude Pod::Elemental::Transformer::Splint from weaver.ini},
-            1 => q{Include Pod::Elemental::Transformer::Splint in weaver.ini},
-        }
-    );
-    has travis => (
-        is => 'rw',
-        isa => Int,
-        default => 1,
-        documentation_alts => {
-            0 => q{Exclude [TravisYML].},
-            1 => q{Include [TravisYML]. By default it tests 5.14+},
-        },
-    );
-    with 'Dist::Iller::Role::Config';
-
-    sub build_file {
-        my $self = shift;
-        return $self->installer =~ m/MakeMaker/ ? 'Makefile.PL' : 'Build.PL';
+has filepath => (
+    is => 'ro',
+    isa => Path,
+    default => 'author-csson.yaml',
+    coerce => 1,
+    documentation => q{Path to the plugin configuration file, relative to the installed share dir location.},
+);
+has is_task => (
+    is => 'ro',
+    isa => Bool,
+    default => 0,
+    documentation => q{If set to a true value it will include [TaskWeaver] instead of [PodWeaver].},
+);
+has installer => (
+    is => 'rw',
+    isa => Str,
+    lazy => 1,
+    default => 'MakeMaker',
+    documentation => q{The installer plugin to be used.},
+);
+has is_private => (
+    is => 'rw',
+    isa => Int,
+    lazy => 1,
+    default => 0,
+    documentation_alts => {
+        0 => q{Include [UploadToCPAN] and [GithubMeta].},
+        1 => q{Include [UploadToStratopan].},
     }
+);
+has homepage => (
+    is => 'rw',
+    isa => Str,
+    lazy => 1,
+    default => sub { sprintf 'https://metacpan.org/release/' . shift->distribution_name },
+    documentation_default => q{https://metacpan.org/release/[distribution_name]},
+    documentation => q{URL to the distribution's homepage.},
+);
+has splint => (
+    is => 'rw',
+    isa => Int,
+    default => 0,
+    documentation_alts => {
+        0 => q{Exclude Pod::Elemental::Transformer::Splint from weaver.ini},
+        1 => q{Include Pod::Elemental::Transformer::Splint in weaver.ini},
+    }
+);
+has travis => (
+    is => 'rw',
+    isa => Int,
+    default => 1,
+    documentation_order => 100,
+    documentation_alts => {
+        0 => q{Exclude [TravisYML].},
+        1 => q{Include [TravisYML]. By default it tests 5.14+},
+    },
+);
+has travis_perl_min => (
+    is => 'ro',
+    isa => Int,
+    lazy => 1,
+    default => '10',
+    documentation_order => 101,
+    documentation => q{Minimum Perl version to test on Travis. All production releases up to (and including) 'travis_perl_max' are automatically included. Only give the minor version number (eg '14' for Perl 5.14).},
+);
+has travis_perl_max => (
+    is => 'ro',
+    isa => Int,
+    lazy => 1,
+    default => '22',
+    documentation_order => 102,
+    documentation => q{Maximum Perl version to test on Travis. See 'travis_perl_min'.}
+);
 
-    sub is_private_release {
-        my $self = shift;
-        return !$ENV{'FAKE_RELEASE'} && $self->is_private ? 1 : 0;
-    }
-    sub is_cpan_release {
-        my $self = shift;
-        return $ENV{'FAKE_RELEASE'} || $self->is_private ? 0 : 1;
-    }
-    sub add_default_github {
-        my $self = shift;
-        # check git config
-        my $add_default_github = 0;
-        my $git_config = path('.git/config');
-        if($git_config->exists) {
-            my $git_config_contents = $git_config->slurp_utf8;
-            if($git_config_contents =~ m{github\.com:([^/]+)/(.+)\.git}) {
-                $add_default_github = 1;
-            }
-            else {
-                say ('[DI/@Author::CSSON] No github url found');
-            }
-        }
-        return $add_default_github;
-    }
+
+with 'Dist::Iller::Role::Config';
+
+sub build_file {
+    my $self = shift;
+    return $self->installer =~ m/MakeMaker/ ? 'Makefile.PL' : 'Build.PL';
 }
 
+sub is_private_release {
+    my $self = shift;
+    return !$ENV{'FAKE_RELEASE'} && $self->is_private ? 1 : 0;
+}
+sub is_cpan_release {
+    my $self = shift;
+    return $ENV{'FAKE_RELEASE'} || $self->is_private ? 0 : 1;
+}
+sub add_default_github {
+    my $self = shift;
+    # check git config
+    my $add_default_github = 0;
+    my $git_config = path('.git/config');
+    if($git_config->exists) {
+        my $git_config_contents = $git_config->slurp_utf8;
+        if($git_config_contents =~ m{github\.com:([^/]+)/(.+)\.git}) {
+            $add_default_github = 1;
+        }
+        else {
+            say ('[DI/@Author::CSSON] No github url found');
+        }
+    }
+    return $add_default_github;
+}
+sub travis_perl {
+    my $self = shift;
+    return join ' ' => map { "5.$_" } grep { $_ >= $self->travis_perl_min && $_ <= $self->travis_perl_max } qw/6 8 10 12 14 16 18 20 22/;
+}
+
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -117,20 +143,20 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 
 =begin HTML
 
-<p><img src="https://img.shields.io/badge/perl-5.12+-brightgreen.svg" alt="Requires Perl 5.12+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-40.9%-red.svg" alt="coverage 40.9%" /></p>
+<p><img src="https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg" alt="Requires Perl 5.10.1+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-47.3%-red.svg" alt="coverage 47.3%" /></p>
 
 =end HTML
 
 
 =begin markdown
 
-![Requires Perl 5.12+](https://img.shields.io/badge/perl-5.12+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON) ![coverage 40.9%](https://img.shields.io/badge/coverage-40.9%-red.svg)
+![Requires Perl 5.10.1+](https://img.shields.io/badge/perl-5.10.1+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON) ![coverage 47.3%](https://img.shields.io/badge/coverage-47.3%-red.svg)
 
 =end markdown
 
 =head1 VERSION
 
-Version 0.0200, released 2016-01-26.
+Version 0.0201, released 2016-01-29.
 
 
 
@@ -144,9 +170,110 @@ Version 0.0200, released 2016-01-26.
 
 Dist::Iller::Config::Author::Csson is a L<Dist::Iller> configuration. The plugin list is in C<share/author-csson.yaml>.
 
-=head1 Attributes
+=head1 ATTRIBUTES
 
 
+=head2 travis
+
+=begin HTML
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Int">Int</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>1</code></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">read/write</td>
+    <td style="text-align: right; padding-right: 6px; padding-left: 6px;"><code>0</code>:</td>
+    <td style="padding-left: 12px;">Exclude [TravisYML].</td>
+</tr>
+<tr>
+    <td>&#160;</td>
+    <td>&#160;</td>
+    <td>&#160;</td>
+    <td style="text-align: right; padding-right: 6px; padding-left: 6px;"><code>1</code>:</td>
+    <td style="padding-left: 12px;">Include [TravisYML]. By default it tests 5.14+</td>
+</tr>
+</table>
+
+<p></p>
+
+=end HTML
+
+=begin markdown
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Int">Int</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>1</code></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">read/write</td>
+    <td style="text-align: right; padding-right: 6px; padding-left: 6px;"><code>1</code>:</td>
+    <td style="padding-left: 12px;">Include [TravisYML]. By default it tests 5.14+</td>
+</tr>
+</table>
+
+<p></p>
+
+=end markdown
+
+=head2 travis_perl_min
+
+=begin HTML
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Int">Int</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>10</code></td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p>Minimum Perl version to test on Travis. All production releases up to (and including) 'travis_perl_max' are automatically included. Only give the minor version number (eg '14' for Perl 5.14).</p>
+
+=end HTML
+
+=begin markdown
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Int">Int</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>10</code></td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p>Minimum Perl version to test on Travis. All production releases up to (and including) 'travis_perl_max' are automatically included. Only give the minor version number (eg '14' for Perl 5.14).</p>
+
+=end markdown
+
+=head2 travis_perl_max
+
+=begin HTML
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Int">Int</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>22</code></td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p>Maximum Perl version to test on Travis. See 'travis_perl_min'.</p>
+
+=end HTML
+
+=begin markdown
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Int">Int</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>22</code></td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p>Maximum Perl version to test on Travis. See 'travis_perl_min'.</p>
+
+=end markdown
+
 =head2 filepath
 
 =begin HTML
@@ -349,47 +476,6 @@ Dist::Iller::Config::Author::Csson is a L<Dist::Iller> configuration. The plugin
 
 =end markdown
 
-=head2 travis
-
-=begin HTML
-
-<table cellpadding="0" cellspacing="0">
-<tr>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Int">Int</a></td>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>1</code></td>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">read/write</td>
-    <td style="text-align: right; padding-right: 6px; padding-left: 6px;"><code>0</code>:</td>
-    <td style="padding-left: 12px;">Exclude [TravisYML].</td>
-</tr>
-<tr>
-    <td>&#160;</td>
-    <td>&#160;</td>
-    <td>&#160;</td>
-    <td style="text-align: right; padding-right: 6px; padding-left: 6px;"><code>1</code>:</td>
-    <td style="padding-left: 12px;">Include [TravisYML]. By default it tests 5.14+</td>
-</tr>
-</table>
-
-<p></p>
-
-=end HTML
-
-=begin markdown
-
-<table cellpadding="0" cellspacing="0">
-<tr>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Int">Int</a></td>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>1</code></td>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">read/write</td>
-    <td style="text-align: right; padding-right: 6px; padding-left: 6px;"><code>1</code>:</td>
-    <td style="padding-left: 12px;">Include [TravisYML]. By default it tests 5.14+</td>
-</tr>
-</table>
-
-<p></p>
-
-=end markdown
-
 =head2 distribution_name
 
 =begin HTML
