@@ -1,29 +1,29 @@
-use 5.14.0;
+use 5.10.1;
+use strict;
 use warnings;
 
-package Dist::Iller::Config::Author::CSSON::MapMetro {
+package Dist::Iller::Config::Author::CSSON::MapMetro;
 
-    use Moose;
-    use Types::Path::Tiny qw/Path/;
-    use namespace::autoclean;
+use Moose;
+use Types::Path::Tiny qw/Path/;
+use namespace::autoclean;
 
-    # ABSTRACT: Dist::Iller config for Map::Metro
-    our $VERSION = '0.0200'; # VERSION
+# ABSTRACT: Dist::Iller config for Map::Metro
+our $VERSION = '0.0201'; # VERSION
 
-    has filepath => (
-        is => 'ro',
-        isa => Path,
-        default => 'author-csson-mapmetro.yaml',
-        coerce => 1,
-        documentation => q{Path to the plugin configuration file, relative to the installed share dir location.},
-    );
-    with 'Dist::Iller::Role::Config';
-    has '+main_module' => (
-        default => 'Dist::Iller::Config::Author::CSSON',
-    );
+has filepath => (
+    is => 'ro',
+    isa => Path,
+    default => 'author-csson-mapmetro.yaml',
+    coerce => 1,
+    documentation => q{Path to the plugin configuration file, relative to the installed share dir location.},
+);
+with 'Dist::Iller::Role::Config';
+has '+main_module' => (
+    default => 'Dist::Iller::Config::Author::CSSON',
+);
 
-    __PACKAGE__->meta->make_immutable;
-}
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -39,7 +39,7 @@ Dist::Iller::Config::Author::CSSON::MapMetro - Dist::Iller config for Map::Metro
 
 =head1 VERSION
 
-Version 0.0200, released 2016-01-26.
+Version 0.0201, released 2016-01-29.
 
 
 
